package com.bureau.devicefingerprint.datacollectors

import android.content.Context
import android.content.Intent
import android.content.pm.ResolveInfo
import android.os.Build
import android.provider.MediaStore
import com.bureau.devicefingerprint.di.DeviceFingerprintScope
import com.bureau.devicefingerprint.models.devicedataholder.CameraInjectionInfo
import com.bureau.devicefingerprint.tools.executeSafe
import javax.inject.Inject

interface CameraInjectionInfoProvider {
    fun getCameraInjection(): CameraInjectionInfo
}

@DeviceFingerprintScope
class CameraInjectionInfoProviderImpl @Inject constructor(private val context: Context) : CameraInjectionInfoProvider {
    override fun getCameraInjection(): CameraInjectionInfo {
        return executeSafe({
            if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.Q) {
                val packageManager = context.packageManager
                val intent = Intent(MediaStore.ACTION_IMAGE_CAPTURE)
                val list: List<ResolveInfo> = packageManager.queryIntentActivities(
                    intent,
                    0
                )
                val packageNames = list.map {
                    it.activityInfo.packageName
                }
                return@executeSafe CameraInjectionInfo(
                    list.size > 1,
                    packageNames
                )
            }

            return@executeSafe CameraInjectionInfo(false, listOf())
        }, CameraInjectionInfo(false, listOf()))
    }
}
