package com.bureau.devicefingerprint.datacollectors

import android.content.Context
import android.content.pm.ApplicationInfo
import android.os.Debug
import com.bureau.devicefingerprint.di.DeviceFingerprintScope
import com.bureau.devicefingerprint.tools.executeSafe
import com.scottyab.rootbeer.RootBeer
import javax.inject.Inject

@DeviceFingerprintScope
class DebuggableInfoProvider @Inject constructor(private val context: Context) {

    fun isDebuggable(): Boolean {
        return executeSafe({
            val isDebuggable = 0 != context.applicationInfo.flags and ApplicationInfo.FLAG_DEBUGGABLE
            isDebuggable
        }, false)
    }

    fun isDebuggerAttached(): Boolean {
        return executeSafe({
            val debuggerAttached = Debug.isDebuggerConnected()
            debuggerAttached
        }, false)
    }

    fun isRooted(): Boolean {
        return executeSafe({
            val rootBeer = RootBeer(context)
            rootBeer.isRooted
        }, false)
    }
}
