package com.bureau.devicefingerprint.datacollectors

import android.content.Context
import android.content.pm.PackageManager
import com.bureau.devicefingerprint.di.DeviceFingerprintScope
import com.bureau.devicefingerprint.tools.Utils
import javax.inject.Inject

interface SocialEngineeringInfoProvider {
    fun getIsSocialEngineeringAppInstalled(): Boolean
}

@DeviceFingerprintScope
class SocialEngineeringInfoProviderImpl @Inject constructor(context: Context) : SocialEngineeringInfoProvider {

    private val packageManager: PackageManager = context.packageManager
    override fun getIsSocialEngineeringAppInstalled(): Boolean {
        SOCIAL_ENGINEERING_APP_PACKAGE_NAMES.forEach {
            if (Utils.isPackageNamePresent(packageManager, it)) {
                return true
            }
        }

        return false
    }

    companion object {
        val SOCIAL_ENGINEERING_APP_PACKAGE_NAMES = listOf(
            "us.zoom.videomeetings",
            "com.google.android.apps.tachyon",
            "com.cisco.webex.meetings",
            "com.microsoft.teams",
            "com.teamviewer.blizz.market",
            "com.anydesk.anydeskandroid",
            "com.microsoft.rdc.androidx"
        )
    }
}
