package com.bureau.devicefingerprint.datacollectors

import android.content.Context
import android.os.Build
import android.telephony.CellInfoGsm
import android.telephony.CellInfoLte
import android.telephony.CellInfoWcdma
import android.telephony.TelephonyManager
import android.util.Log
import androidx.appcompat.app.AppCompatActivity
import com.bureau.devicefingerprint.di.DeviceFingerprintScope
import com.bureau.devicefingerprint.models.devicedataholder.TelecomBaseStationInfo
import com.bureau.devicefingerprint.tools.executeSafe
import javax.inject.Inject

@DeviceFingerprintScope
class TelecomBaseStationInfoProvider @Inject constructor(private val context: Context) {
    fun getTelecomBaseStationInfo(): TelecomBaseStationInfo {
        return executeSafe({
            var mcc = ""
            var mnc = ""
            var cid = ""
            var lac = ""
            var type = ""
            val tel =
                context.getSystemService(AppCompatActivity.TELEPHONY_SERVICE) as TelephonyManager
            val cellInfoList = tel.getAllCellInfo()
            if (cellInfoList != null && cellInfoList.isNotEmpty()) {
                when (val mainBSCellInfo = cellInfoList.get(0)) {
                    is CellInfoWcdma -> {
                        // 联通3G
                        val cellIdentityWcdma = mainBSCellInfo.cellIdentity
                        type = RadioType.CDMA

                        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.P) {
                            mcc = cellIdentityWcdma.mccString ?: "0"
                            mnc = cellIdentityWcdma.mncString ?: "0"
                        } else {
                            mcc = cellIdentityWcdma.mcc.toString()
                            mnc = cellIdentityWcdma.mnc.toString()
                        }

                        cid = cellIdentityWcdma.cid.toString()
                        lac = cellIdentityWcdma.lac.toString()
                    }

                    is CellInfoLte -> {
                        // 4G
                        val cellIdentityLte = mainBSCellInfo.cellIdentity
                        type = RadioType.LTE

                        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.P) {
                            mcc = cellIdentityLte.mccString ?: "0"
                            mnc = cellIdentityLte.mncString ?: "0"
                        } else {
                            mcc = cellIdentityLte.mcc.toString()
                            mnc = cellIdentityLte.mnc.toString()
                        }

                        cid = cellIdentityLte.ci.toString()
                        lac = cellIdentityLte.tac.toString()
                    }

                    is CellInfoGsm -> {
                        // 2G
                        val cellIdentityGsm = mainBSCellInfo.cellIdentity
                        type = RadioType.GSM

                        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.P) {
                            mcc = cellIdentityGsm.mccString ?: "0"
                            mnc = cellIdentityGsm.mncString ?: "0"
                        } else {
                            mcc = cellIdentityGsm.mcc.toString()
                            mnc = cellIdentityGsm.mnc.toString()
                        }

                        cid = cellIdentityGsm.cid.toString()
                        lac = cellIdentityGsm.lac.toString()
                    }

                    else -> {
                        // 电信2/3G
                        Log.e(
                            "balatag",
                            "CDMA CellInfo................................................"
                        )
                    }
                }
            }

            TelecomBaseStationInfo(type, mcc, mnc, lac, cid)
        }, TelecomBaseStationInfo())
    }

    object RadioType {
        const val GSM = "gsm"
        const val CDMA = "cdma"
        const val UMTS = "umts"
        const val LTE = "lte"
    }
}
