package com.bureau.devicefingerprint.datacollectors

import android.content.Context
import android.net.wifi.WifiManager
import com.bureau.devicefingerprint.di.DeviceFingerprintScope
import com.bureau.devicefingerprint.tools.executeSafe
import javax.inject.Inject

interface WifiInfoProvider {
    fun getSSID(): String
    fun getBSSID(): String
    fun getRSSI(): Int
}

@DeviceFingerprintScope
class WifiInfoProviderImpl @Inject constructor(context: Context) : WifiInfoProvider {
    private val wifiManager = context.applicationContext.getSystemService(Context.WIFI_SERVICE) as WifiManager
    private val wifiInfo = executeSafe({ wifiManager.connectionInfo }, null)
    override fun getSSID(): String {
        return executeSafe({
            wifiInfo?.ssid ?: ""
        }, "")
    }

    override fun getBSSID(): String {
        return executeSafe({
            wifiInfo?.bssid ?: ""
        }, "")
    }

    override fun getRSSI(): Int {
        return executeSafe({
            wifiInfo?.rssi ?: -1
        }, -1)
    }
}
