package com.bureau.devicefingerprint.di

import android.app.ActivityManager
import android.app.Application
import android.app.KeyguardManager
import android.app.admin.DevicePolicyManager
import android.content.ContentResolver
import android.content.Context
import android.hardware.SensorManager
import android.hardware.input.InputManager
import android.media.RingtoneManager
import androidx.core.hardware.fingerprint.FingerprintManagerCompat
import com.bureau.base.AppInfo
import com.bureau.devicefingerprint.datacollectors.DevicePersonalizationInfoProvider
import com.bureau.devicefingerprint.datacollectors.DevicePersonalizationInfoProviderImpl
import com.bureau.devicefingerprint.datacollectors.DeviceSecurityInfoProvider
import com.bureau.devicefingerprint.datacollectors.DeviceSecurityInfoProviderImpl
import com.bureau.devicefingerprint.datacollectors.FingerprintSensorInfoProvider
import com.bureau.devicefingerprint.datacollectors.FingerprintSensorInfoProviderImpl
import com.bureau.devicefingerprint.datacollectors.GpuInfoProvider
import com.bureau.devicefingerprint.datacollectors.GpuInfoProviderImpl
import com.bureau.devicefingerprint.datacollectors.InputDeviceDataSource
import com.bureau.devicefingerprint.datacollectors.InputDevicesDataSourceImpl
import com.bureau.devicefingerprint.datacollectors.PackageManagerDataSource
import com.bureau.devicefingerprint.datacollectors.PackageManagerDataSourceImpl
import com.bureau.devicefingerprint.datacollectors.SensorDataSource
import com.bureau.devicefingerprint.datacollectors.SensorDataSourceImpl
import dagger.Module
import dagger.Provides

@Module
class DeviceFingerprintModule {
    @Provides
    @DeviceFingerprintScope
    fun injectContext(application: Application): Context = application

    @Provides
    @DeviceFingerprintScope
    fun injectContentResolver(context: Context): ContentResolver = context.contentResolver

    @Provides
    @DeviceFingerprintScope
    fun injectDevicePersonalisationInfo(context: Context): DevicePersonalizationInfoProvider = DevicePersonalizationInfoProviderImpl(
        RingtoneManager(context),
        context.assets,
        context.resources.configuration
    )

    @Provides
    @DeviceFingerprintScope
    fun injectDeviceSecurityInfo(context: Context): DeviceSecurityInfoProvider = DeviceSecurityInfoProviderImpl(
        context.getSystemService(Context.DEVICE_POLICY_SERVICE) as DevicePolicyManager,
        context.getSystemService(Context.KEYGUARD_SERVICE) as KeyguardManager
    )

    @Provides
    @DeviceFingerprintScope
    fun injectFingerprintSensorInfo(context: Context): FingerprintSensorInfoProvider = FingerprintSensorInfoProviderImpl(
        FingerprintManagerCompat.from(context)
    )

    @Provides
    @DeviceFingerprintScope
    fun injectGpuInfo(context: Context): GpuInfoProvider = GpuInfoProviderImpl(context.getSystemService(Context.ACTIVITY_SERVICE) as ActivityManager)

    @Provides
    @DeviceFingerprintScope
    fun injectInputDeviceData(context: Context): InputDeviceDataSource = InputDevicesDataSourceImpl(context.getSystemService(Context.INPUT_SERVICE) as InputManager)

    @Provides
    @DeviceFingerprintScope
    fun injectPackageManagerData(context: Context): PackageManagerDataSource = PackageManagerDataSourceImpl(context.packageManager, context)

    @Provides
    @DeviceFingerprintScope
    fun injectSensorData(context: Context): SensorDataSource = SensorDataSourceImpl(context.getSystemService(Context.SENSOR_SERVICE) as SensorManager)

    @Provides
    @DeviceFingerprintScope
    fun injectAppInfo(context: Context): AppInfo = AppInfo(context)
}
