package com.bureau.devicefingerprint.tools

import android.text.TextUtils
import kotlin.math.roundToInt

class TimeLoggerUtil {
    private var _startTimeMillis: Long = 0
    private var _lastTimeMillis: Long = 0
    private var _logMap: HashMap<String, String> = HashMap()

    private fun getCurrentTime(): Long {
        return System.currentTimeMillis()
    }

    fun startTrace() {
        _startTimeMillis = getCurrentTime()
        _lastTimeMillis = _startTimeMillis
    }

    fun endTrace() {
        _startTimeMillis = 0
        _lastTimeMillis = 0
        _logMap = hashMapOf()
    }

    fun logTrace(key: String) {
        if (!TextUtils.isEmpty(key)) {
            _logMap[key] = getRoundedTimeSinceCurrTime(_lastTimeMillis).toString()
        }
        _lastTimeMillis = getCurrentTime()
    }

    fun getTimeSinceStart(): Int {
        return if (0 < _startTimeMillis) {
            getRoundedTimeSinceCurrTime(_startTimeMillis)
        } else {
            0
        }
    }

    private fun getRoundedTimeSinceCurrTime(time: Long): Int {
        return ((getCurrentTime() - time) / 100.0).roundToInt() * 100
    }

    fun isTracing(): Boolean {
        return 0 < _startTimeMillis
    }

    /*fun raiseAnalyticsEvent(eventName: String, eventProperties: Map<String, String>?) {
        val event = AnalyticsEvent(eventName, AnalyticsEvent.ALWAYS)
        if (eventProperties != null) {
            for ((key, value) in eventProperties) {
                Log.d("myTag", "raiseAnalyticsEvent: $key  $value")
                event.addProperty(key, value)
            }
        }

        for ((key, value) in _logMap) {
            Log.d("myTag", "raiseAnalyticsEvent: $key  $value")
            event.addProperty(key, value)
        }

        EventBus.getDefault().post(event)
    }*/

    fun getEventMap(): HashMap<String, String> {
        return _logMap
    }

    companion object {
        val timeLoggerUtil = TimeLoggerUtil()
    }
}
